pub struct MockSecretsApi {
SecretsApi_expectations: MockSecretsApi_SecretsApi,
}Fields
SecretsApi_expectations: MockSecretsApi_SecretsApiImplementations
Sourceimpl MockSecretsApi
impl MockSecretsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockSecretsApi
impl MockSecretsApi
Sourcepub fn expect_bulk_delete(&mut self) -> &mut Expectation
pub fn expect_bulk_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_delete method
Sourcepub fn expect_create(&mut self) -> &mut Expectation
pub fn expect_create(&mut self) -> &mut Expectation
Create an Expectation for mocking the create method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_secrets_by_ids(&mut self) -> &mut Expectation
pub fn expect_get_secrets_by_ids(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_secrets_by_ids method
Sourcepub fn expect_get_secrets_by_project(&mut self) -> &mut Expectation
pub fn expect_get_secrets_by_project(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_secrets_by_project method
Sourcepub fn expect_get_secrets_sync(&mut self) -> &mut Expectation
pub fn expect_get_secrets_sync(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_secrets_sync method
Sourcepub fn expect_list_by_organization(&mut self) -> &mut Expectation
pub fn expect_list_by_organization(&mut self) -> &mut Expectation
Create an Expectation for mocking the list_by_organization method
Sourcepub fn expect_update_secret(&mut self) -> &mut Expectation
pub fn expect_update_secret(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_secret method